<?php

namespace Lession\Lession\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Lession\Lession\Http\Requests\LessionRequest;
use Lession\Lession\Models\Lession;

/**
 * Admin web controller class.
 */
class LessionWorkflowController extends BaseController
{

    /**
     * Workflow controller function for lession.
     *
     * @param Model   $lession
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(LessionRequest $request, Lession $lession, $step)
    {

        try {

            $lession->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('lession::lession.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/lession/lession/' . $lession->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/lession/lession/' . $lession->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for lession.
     *
     * @param Model   $lession
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Lession $lession, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $lession->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('lession::lession.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lession::admin.lession.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lession::admin.lession.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lession::admin.lession.message', $data)->render();

        }

    }
}
