<?php

namespace Lession\Lession\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lession\Lession\Models\Lession;

class LessionPolicy
{

    /**
     * Determine if the given user can view the lession.
     *
     * @param UserPolicy $user
     * @param Lession $lession
     *
     * @return bool
     */
    public function view(UserPolicy $user, Lession $lession)
    {
        if ($user->canDo('lession.lession.view') && $user->isAdmin()) {
            return true;
        }

        return $lession->user_id == user_id() && $lession->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lession.
     *
     * @param UserPolicy $user
     * @param Lession $lession
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lession.lession.create');
    }

    /**
     * Determine if the given user can update the given lession.
     *
     * @param UserPolicy $user
     * @param Lession $lession
     *
     * @return bool
     */
    public function update(UserPolicy $user, Lession $lession)
    {
        if ($user->canDo('lession.lession.edit') && $user->isAdmin()) {
            return true;
        }

        return $lession->user_id == user_id() && $lession->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lession.
     *
     * @param UserPolicy $user
     * @param Lession $lession
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Lession $lession)
    {
        return $lession->user_id == user_id() && $lession->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lession.
     *
     * @param UserPolicy $user
     * @param Lession $lession
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Lession $lession)
    {
        if ($user->canDo('lession.lession.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lession.
     *
     * @param UserPolicy $user
     * @param Lession $lession
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Lession $lession)
    {
        if ($user->canDo('lession.lession.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
