<?php

namespace Lession\Lession\Providers;

use Illuminate\Support\ServiceProvider;

class LessionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'lession');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'lession');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerLession();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerLession()
    {
        $this->app->bind('lession', function($app) {
            return new Lession($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Lession', 'Lavalite\Lession\Facades\Lession');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('lession.lession', function ($app) {
            return $this->app->make('Lession\Lession\Lession');
        });

                // Bind Lession to repository
        $this->app->bind(
            'Lession\Lession\Interfaces\LessionRepositoryInterface',
            \Lession\Lession\Repositories\Eloquent\LessionRepository::class
        );

        $this->app->register(\Lession\Lession\Providers\AuthServiceProvider::class);
                $this->app->register(\Lession\Lession\Providers\EventServiceProvider::class);
        
        $this->app->register(\Lession\Lession\Providers\RouteServiceProvider::class);
                $this->app->register(\Lession\Lession\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and lession's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/lession.php', 'lession'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeLession::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lession.lession'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lession/lession.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/lession')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/lession')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
