<?php

namespace Lession\Lession\Workflow;

use Lession\Lession\Models\Lession;
use Validator;

class LessionValidator
{

    /**
     * Determine if the given lession is valid for complete status.
     *
     * @param Lession $lession
     *
     * @return bool / Validator
     */
    public function complete(Lession $lession)
    {
        return Validator::make($lession->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given lession is valid for verify status.
     *
     * @param Lession $lession
     *
     * @return bool / Validator
     */
    public function verify(Lession $lession)
    {
        return Validator::make($lession->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given lession is valid for approve status.
     *
     * @param Lession $lession
     *
     * @return bool / Validator
     */
    public function approve(Lession $lession)
    {
        return Validator::make($lession->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given lession is valid for publish status.
     *
     * @param Lession $lession
     *
     * @return bool / Validator
     */
    public function publish(Lession $lession)
    {
        return Validator::make($lession->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given lession is valid for archive status.
     *
     * @param Lession $lession
     *
     * @return bool / Validator
     */
    public function archive(Lession $lession)
    {
        return Validator::make($lession->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given lession is valid for unpublish status.
     *
     * @param Lession $lession
     *
     * @return bool / Validator
     */
    public function unpublish(Lession $lession)
    {
        return Validator::make($lession->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
